@@ -21,8 +21,6 @@ from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
 from collective.portlet.relateditems import RelatedItemsMessageFactory as _
 
-# Hardlink to contentleadimage product
-
 try:
     from collective.contentleadimage.config import IMAGE_FIELD_NAME
     from collective.contentleadimage.leadimageprefs import ILeadImagePrefsForm
@@ -171,7 +169,6 @@ class Renderer(base.Renderer):
     def prefs(self):
         res = ''
         if LEADIMAGE_EXISTS:
-            print 'prefs called'
             portal = getUtility(IPloneSiteRoot)
             res = ILeadImagePrefsForm(portal)
         return res
@@ -204,9 +201,10 @@ class Renderer(base.Renderer):
         contents = []
         # Collection
         if IATTopic.providedBy(self.context):
-            # TODO: This limit is not working...
-            #contents = self.context.queryCatalog(contentFilter={'sort_limit':6})
-            contents = self.context.queryCatalog(contentFilter={'sort_limit':6})            
+            try:
+                contents = self.context.queryCatalog(contentFilter={'sort_limit':6})
+            except:
+                pass
         # probably a folder
         else:
             contents = self.context.getFolderContents()
@@ -274,8 +272,7 @@ class Renderer(base.Renderer):
                 contents += context.getBackReferences()
             except Exception, e:
                 pass
-
-        
+     
         contents += folder_contents
         
         search_query = self._itemsQuery(contents)
